pymcr.tests package
===================

Submodules
----------

pymcr.tests.test\_condition module
----------------------------------

.. automodule:: pymcr.tests.test_condition
   :members:
   :undoc-members:
   :show-inheritance:

pymcr.tests.test\_constraints module
------------------------------------

.. automodule:: pymcr.tests.test_constraints
   :members:
   :undoc-members:
   :show-inheritance:

pymcr.tests.test\_external\_regressors module
---------------------------------------------

.. automodule:: pymcr.tests.test_external_regressors
   :members:
   :undoc-members:
   :show-inheritance:

pymcr.tests.test\_mcr module
----------------------------

.. automodule:: pymcr.tests.test_mcr
   :members:
   :undoc-members:
   :show-inheritance:

pymcr.tests.test\_mcr\_sklearn\_like module
-------------------------------------------

.. automodule:: pymcr.tests.test_mcr_sklearn_like
   :members:
   :undoc-members:
   :show-inheritance:

pymcr.tests.test\_metrics module
--------------------------------

.. automodule:: pymcr.tests.test_metrics
   :members:
   :undoc-members:
   :show-inheritance:

pymcr.tests.test\_regressors module
-----------------------------------

.. automodule:: pymcr.tests.test_regressors
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pymcr.tests
   :members:
   :undoc-members:
   :show-inheritance:
